@@ -5,7 +5,7 @@ use warnings;
 package Sub::MultiMethod;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.905';
+our $VERSION   = '0.906';
 
 use B ();
 use Exporter::Shiny qw( multimethod multimethods_from_roles monomethod );
@@ -340,7 +340,7 @@ sub install_candidate {
 				$CLEANUP{"$coderef"} = [ $target, refaddr($sub_name) ];
 				return( $$sub_name = $coderef );
 			}
-			elsif (is_CodeRef $$sub_name || is_Object $$sub_name) {
+			elsif (is_CodeRef $$sub_name or is_Object $$sub_name) {
 				if ( $me->known_dispatcher($$sub_name) ) {
 					return $$sub_name;
 				}
@@ -361,7 +361,7 @@ sub install_candidate {
 		}
 		require Carp;
 		Carp::croak(sprintf(
-			'Expected string or reference to coderef as sub name, but got: %s',
+			'Expected string or reference to coderef as sub name, but got: %s %s',
 			$sub_name,
 		));
 	}
